@@ -26,6 +26,8 @@ class XGBoost(ModelConnector):
         gamma: Optional[float] = None,
         reg_alpha: Optional[float] = None,
         reg_lambda: Optional[float] = None,
+        fit_on_null_values: Optional[bool] = None,
+        predict_on_null_values: Optional[bool] = None,
     ) -> None:
         super().__init__(
             uuid=UUID("b78ff94a-27b1-4986-a88a-536661239bb2"),
@@ -41,5 +43,7 @@ class XGBoost(ModelConnector):
                 gamma=gamma,
                 reg_alpha=reg_alpha,
                 reg_lambda=reg_lambda,
+                fit_on_null_values=fit_on_null_values,
+                predict_on_null_values=predict_on_null_values,
             ),
         )
